Module array_plot

Module array_plot 

Array Plot

Displays a table of values with different shades.

Functions

  • array_plot - Generates an ArrayPlotBuilder from a table.
  • bin_arr - Bins a float table to a specific number of values.

Structs

ArrayPlotBuilder
Builder for an Array Plot Set various options for plotting the data.

Functions

array_plot
Displays a table of values with different shades.
bin_arr
Bins an array of floats into n evenly-spaced values.