Module array_plot
cgrustplot
1.2.2
Module array_
plot
Sections
Array Plot
Functions
Module Items
Structs
Functions
In cgrustplot::
plots
cgrustplot
::
plots
Module
array_
plot

Array Plot
Displays a table of values with different shades.

Functions
array_plot
- Generates an ArrayPlotBuilder from a table.
bin_arr
- Bins a float table to a specific number of values.
Structs

Array
Plot
Builder
Builder for an Array Plot Set various options for plotting the data.
Functions

array_
plot
Displays a table of values with different shades.
bin_arr
Bins an array of floats into n evenly-spaced values.